@@ -1,5 +1,5 @@
-__version__ = "1.0.1"
-__description__ = "help you play your API like building blocks !"
+__version__ = "1.1.4"
+__description__ = "Build fast,Test fast!"
 __image__ = r"""
          /\                         .-.                 .:                      
      _  / |      .;;.    .-          .;|/:              ::                      
