@@ -9,7 +9,9 @@ from loguru import logger
 from aomaker import __version__, __description__, __image__
 from aomaker.scaffold import init_parser_scaffold, main_scaffold
 from aomaker.make import init_make_parser, main_make
-from aomaker.make_testcase import init_make_case_parser, main_make_case
+from aomaker.make_testcase import init_make_case_parser, main_make_case, init_case_parser, main_case
+from aomaker.extension.har_parse import init_har2yaml_parser, main_har2yaml
+from aomaker.extension.recording import init_record_parser, main_record
 
 
 def init_parser_run(subparsers):
@@ -32,6 +34,7 @@ def set_conf_file(env):
             sys.exit(1)
         with open('conf/config.yaml', 'w') as f:
             yaml.safe_dump(doc, f, default_flow_style=False)
+        logger.info(f'Current Test Env: {env}')
     else:
         logger.error('配置文件conf/config.yaml不存在')
         sys.exit(1)
@@ -39,10 +42,12 @@ def set_conf_file(env):
 
 def main_run(extra_args):
     logger.info("start to run")
-    if "--pytest-tmreport-name=report/test_report.html" not in extra_args:
-        extra_args.append("--pytest-tmreport-path=report/")
-        extra_args.append("--pytest-tmreport-name=test_report.html")
-
+    # if "--pytest-tmreport-name=report/test_report.html" not in extra_args:
+    #     extra_args.append("--pytest-tmreport-path=report/")
+    #     extra_args.append("--pytest-tmreport-name=test_report.html")
+    extra_args.append("--html=report/aomaker_report.html")
+    extra_args.append("--self-contained-html")
+    extra_args.append("--capture=sys")
     logger.info(f"start to run tests with pytest. AOMaker version: {__version__}")
     return pytest.main(extra_args)
 
@@ -57,10 +62,11 @@ def main():
     subparsers = parser.add_subparsers(help="sub-command help")
     sub_parser_scaffold = init_parser_scaffold(subparsers)
     sub_parser_make = init_make_parser(subparsers)
-    # sub_parser_s2y = init_swagger2yaml_parser(subparsers)
-    sub_parser_a2c = init_make_case_parser(subparsers)
+    sub_parser_case = init_case_parser(subparsers)
+    sub_parser_mcase = init_make_case_parser(subparsers)
+    sub_parser_har2y = init_har2yaml_parser(subparsers)
     sub_parser_run = init_parser_run(subparsers)
-
+    sub_parser_record = init_record_parser(subparsers)
     if len(sys.argv) == 1:
         # aomker
         print(__image__)
@@ -78,32 +84,57 @@ def main():
             # aomaker startproject
             sub_parser_scaffold.print_help()
         elif sys.argv[1] == "make":
+            # aomaker make
             sub_parser_make.print_help()
-        # elif sys.argv[1] == "s2y":
-        #     sub_parser_s2y.print_help()
+        elif sys.argv[1] == "case":
+            # aomaker case
+            sub_parser_case.print_help()
         elif sys.argv[1] == "mcase":
-            sub_parser_a2c.print_help()
+            # aomaker mcase
+            sub_parser_mcase.print_help()
+        elif sys.argv[1] == "har2y":
+            # aomaker har2y
+            sub_parser_har2y.print_help()
+        elif sys.argv[1] == "record":
+            # aomaker record
+            sub_parser_record.print_help()
         elif sys.argv[1] == "run":
             # aomaker run
             sub_parser_run.print_help()
         sys.exit(0)
-    elif (
-            len(sys.argv) == 3 and sys.argv[1] == "run" and sys.argv[2] in ["-h", "--help"]
-    ):
-        # aomaker run -h
-        pytest.main(["-h"])
+    elif len(sys.argv) == 3:
+        if sys.argv[1] == "run" and sys.argv[2] in ["-h", "--help"]:
+            # aomaker run -h
+            pytest.main(["-h"])
+            sys.exit(0)
+        elif sys.argv[1] == "run" and sys.argv[2] == "-e":
+            # aomaker run -e xxx
+            print('please input env name in "conf/config.yaml"')
+            sys.exit(0)
+        elif sys.argv[1] == "make" and sys.argv[2] == "-t":
+            # aomaker make -s xxx
+            print('please input file path(YAML or Swagger)')
+            # print('please input template:"qingcloud" or "restful".default template style:restful')
+            sys.exit(0)
+    # elif sys.argv[1] == "run" and sys.argv[2] == "-e":
+    #     # aomaker run -e xxx
+    #     # print('please input env name in "conf/config.yaml"')
+    #     # sys.exit(0)
+    #
+    #     set_conf_file(sys.argv[3])
+    elif sys.argv[1] == "make" and sys.argv[2] == "-t" and sys.argv[3] not in ["qingcloud", "restful"]:
+        print('please input template style:qingcloud or restful')
         sys.exit(0)
-    elif sys.argv[1] == "run" and sys.argv[2] == "-e":
-        # aomaker run -e xxx
-        logger.info(sys.argv[3])
-        set_conf_file(sys.argv[3])
+    elif sys.argv[1] == "har2y":
+        if not sys.argv[-1].endswith('.yaml') or sys.argv[-1].endswith('.har'):
+            print("please input YAML/HAR file path.")
+            sys.exit(1)
 
     extra_args = []
     if len(sys.argv) >= 2 and sys.argv[1] in ["run"]:
         args, extra_args = parser.parse_known_args()
     else:
         args = parser.parse_args()
-
     if args.version:
         print(f"{__version__}")
         sys.exit(0)
@@ -112,15 +143,23 @@ def main():
         main_scaffold(args)
         print('Project created successfully!')
     elif sys.argv[1] == "make":
-        main_make(args.param)
+        if sys.argv[2] == '-t' and sys.argv[3] == 'qingcloud':
+            main_make(args.file_path, template=args.template)
+        else:
+            main_make(args.file_path)
         print('API object generated successfully!')
-    # elif sys.argv[1] == "s2y":
-    #     main_swagger2yaml(args.param)
-    #     print('API definition of YAML generated successfully from swagger!')
+    elif sys.argv[1] == "case":
+        main_case(args.file_path)
     elif sys.argv[1] == "mcase":
-        main_make_case(args.data_path)
+        main_make_case(args.file_path)
         print('Test cases generated successfully from test data!')
+    elif sys.argv[1] == "har2y":
+        main_har2yaml(args)
+    elif sys.argv[1] == "record":
+        main_record(args)
     elif sys.argv[1] == "run":
+        if sys.argv[2] == "-e":
+            set_conf_file(sys.argv[3])
         sys.exit(main_run(extra_args))
 
 
@@ -136,7 +175,7 @@ def main_arun_alias():
             pytest.main(["-h"])
             sys.exit(0)
         else:
-            # arun /path/to/testcase
+            # arun
             sys.argv.insert(1, "run")
     else:
         sys.argv.insert(1, "run")
@@ -151,5 +190,13 @@ def main_make_alias():
     main()
 
 
+def main_record_alias():
+    """ command alias
+        arec = aomaker record
+    """
+    sys.argv.insert(1, "record")
+    main()
+
+
 if __name__ == '__main__':
     main()
